@@ -23,9 +23,9 @@
  * CVS Information:
  *
  * $Source: /home/globdev/CVS/globus-packages/gass/transfer/source/library/globus_gass_transfer_proto.c,v $
- * $Date: 2006/01/19 05:54:50 $
- * $Revision: 1.13 $
- * $Author: mlink $
+ * $Date: 2009/11/11 19:48:37 $
+ * $Revision: 1.15 $
+ * $Author: bester $
  */
 #endif /* GLOBUS_DONT_DOCUMENT_INTERNAL */
 
@@ -151,7 +151,7 @@ globus_gass_transfer_proto_receive_complete(
  * has decided that a new request can be accepted on this particular listener.
  * It must only be called after the GASS Transfer Library has called the
  * @link globus_gass_transfer_listener_proto_t::listen listen function @endlink
- * in a @link #globus_gass_transfer_listener_proto_t protocol module-specific
+ * in a #globus_gass_transfer_listener_proto_t protocol module-specific
  * listener structure.
  *
  * @param listener
@@ -566,10 +566,15 @@ globus_gass_transfer_proto_new_listener_request(
 	globus_i_gass_transfer_unlock();
 	l->close_callback(l->close_callback_arg,
 			  listener);
+
+	l->proto->destroy(l->proto,
+			  listener);
+
 	globus_i_gass_transfer_lock();
 
 	/* Destroy GASS's reference to this listener */
 	globus_i_gass_transfer_listener_destroy(listener);
+	globus_i_gass_transfer_listener_destroy(listener);
 
 	globus_i_gass_transfer_unlock();
 
